#Bethany Allen   12th June 2018 (edited 12th November 2018, 7th February 2019, 9th July 2020)
#Code to plot graphs of raw diversity with latitude of the PBDB data (from a csv)

#setwd("#####")

#Load packages
library(tidyverse)

#Create a vector giving the chronological order of stages
stages <- c("Roadian", "Wordian", "Capitanian", "Wuchiapingian", "Changhsingian", "Induan", "Olenekian",
            "Anisian", "Ladinian")

#Define latitude bins
bins <- seq(from = -90, to = 90, by = 20); labels <- seq(from = -80, to = 80, by = 20)

#Read in dataset
fossils <- read_csv("data/PT_brach_biv_clean.csv")
glimpse(fossils)


###Designate the taxonomic resolution, "species" or "genera"###
tax_res <- "genera"

all_gradients <- data.frame()

for (j in 1:length(stages)){
  #Apply filters
  fossils_stage <- filter(fossils, stage_bin == stages[j])
  if (tax_res == "species"){fossils_stage <- fossils_stage %>% filter(accepted_rank == "species") %>%
    filter(!str_detect(identified_name, " cf")) %>% filter(!str_detect(identified_name, " aff")) %>%
    filter(!str_detect(identified_name, '"')) %>% filter(!str_detect(identified_name, " \\?")) %>%
    filter(!str_detect(identified_name, "ex gr."))
  } else if (tax_res == "genera"){fossils_stage <- filter(fossils_stage, !is.na(genus))}

  #Filter unique taxa
  #Remove repeats of names, to get one occurrence per unique taxon per stage
  if (tax_res == "species"){
    unique_by_bin <- distinct(fossils_stage, accepted_name, paleolat_code, .keep_all = T)
  } else if (tax_res == "genera") {
    unique_by_bin <- distinct(fossils_stage, genus, paleolat_code, .keep_all = T)
  }

  #Split into brachiopods and bivalves
  brachs_by_lat <- unique_by_bin %>% filter(phylum == "Brachiopoda") %>% count(paleolat_code)
  bivs_by_lat <- unique_by_bin %>% filter(phylum == "Mollusca") %>% count(paleolat_code)

  #Fill in any gaps
  for(i in 1:length(labels)) {
    if((labels[i] %in% brachs_by_lat$paleolat_code) == FALSE) brachs_by_lat <- rbind(brachs_by_lat, c(labels[i], 0))
    if((labels[i] %in% bivs_by_lat$paleolat_code) == FALSE) bivs_by_lat <- rbind(bivs_by_lat, c(labels[i], 0))
  }

  #Reorder for ease of checking
  brachs_by_lat <- arrange(brachs_by_lat, desc(paleolat_code))
  bivs_by_lat <- arrange(bivs_by_lat, desc(paleolat_code))

  #Combine into single data frame
  brachs_by_lat$clade <- "Brachiopods"
  bivs_by_lat$clade <- "Bivalves"
  lat_counts <- rbind(brachs_by_lat, bivs_by_lat)
  
  #Bind to overall data frame
  lat_counts$stage <- stages[j]
  all_gradients <- rbind(all_gradients, lat_counts)
}

#Convert to numbers for plotting
all_gradients$paleolat_code <- as.numeric(as.character(all_gradients$paleolat_code))

#Save LDGs
write.csv(all_gradients, "data/Raw_LDGs.csv", row.names = F)

#Filter to one stage for plotting
to_plot <- filter(all_gradients, stage == "Roadian")

#Plot
ggplot(to_plot, aes(x = paleolat_code, y = n, group = clade, colour = clade)) +
  geom_line(size = 2) + geom_point(size = 2) + labs(x = "Palaeolatitude", y = "Raw richness") +
  coord_flip() + scale_x_continuous(limits = c(-90, 90)) +
  geom_vline(aes(xintercept = 0), colour = "black") + 
  scale_colour_manual(values = c("black", "grey")) + theme_classic()
