#Bethany Allen   16th April 2021
#Code to plot brachiopod and bivalve sampling through space and time

#setwd("#####")

#Load packages
library(tidyverse)

#Create a vector giving the chronological order of stages
stages <- c("Roadian", "Wordian", "Capitanian", "Wuchiapingian", "Changhsingian", "Induan", "Olenekian",
            "Anisian", "Ladinian")

#Define latitude bins
bins <- seq(from = -90, to = 90, by = 20); labels <- seq(from = -80, to = 80, by = 20)

#Read in data
fossils <- read_csv("data/PT_brach_biv_clean.csv")

#Indicate phyla
phyla <- c("Brachiopoda", "Mollusca")

#Create empty data frames
occ_counts <- data.frame(); cell_counts <- data.frame(); pooled_colls <- data.frame()


for (p in 1:length(phyla)){
  one_clade <- filter(fossils, phylum == phyla[p])
  
  for (k in 1:length(stages)){
  
    #Occurrence counts
    occs_stage <- one_clade %>% filter(stage_bin == stages[k]) %>% count(paleolat_code)
    for(m in 1:length(labels)) {
      if((labels[m] %in% occs_stage$paleolat_code) == FALSE) occs_stage <- rbind(occs_stage, c(labels[m], 0))
    }
    occs_stage$stage <- stages[k]
    occs_stage$clade <- phyla[p]
    occ_counts <- rbind(occ_counts, occs_stage)
  
    #Cell counts
    cells_stage <- one_clade %>% filter(stage_bin == stages[k]) %>%
      distinct(cell_code, .keep_all = T) %>% count(paleolat_code)
    for(n in 1:length(labels)) {
      if((labels[n] %in% cells_stage$paleolat_code) == FALSE) cells_stage <- rbind(cells_stage, c(labels[n], 0))
    }
    cells_stage$stage <- stages[k]
    cells_stage$clade <- phyla[p]
    cell_counts <- rbind(cell_counts, cells_stage)
  
    #Pooled collections
    pooled_colls_stage <- one_clade %>% filter(stage_bin == stages[k]) %>%
      distinct(collection_no_pooled, .keep_all = T) %>% count(paleolat_code)
    for(o in 1:length(labels)) {
      if((labels[o] %in% pooled_colls_stage$paleolat_code) == FALSE) pooled_colls_stage <- rbind(pooled_colls_stage, c(labels[o], 0))
    }
    pooled_colls_stage$stage <- stages[k]
    pooled_colls_stage$clade <- phyla[p]
    pooled_colls <- rbind(pooled_colls, pooled_colls_stage)
  }
}

#Plot occurrences
occ_counts_stage <- filter(occ_counts, stage == "Roadian")

ggplot(occ_counts_stage, aes(x = paleolat_code, y = n, group = clade, colour = clade)) +
  geom_line(size = 2) + geom_point(size = 2) + labs(x = "Palaeolatitude", y = "Occurrence counts") +
  coord_flip() + scale_x_continuous(limits = c(-90, 90)) +
  geom_vline(aes(xintercept = 0), colour = "black") + 
  scale_colour_manual(values = c("grey", "black")) + theme_classic()


#Plot cell counts
cell_counts_stage <- filter(cell_counts, stage == "Roadian")

ggplot(cell_counts_stage, aes(x = paleolat_code, y = n, group = clade, colour = clade)) +
  geom_line(size = 2) + geom_point(size = 2) + labs(x = "Palaeolatitude", y = "Equal area grid cells") +
  coord_flip() + scale_x_continuous(limits = c(-90, 90)) +
  geom_vline(aes(xintercept = 0), colour = "black") + 
  scale_colour_manual(values = c("grey", "black")) + theme_classic()


#Plot pooled collections
pooled_colls_stage <- filter(pooled_colls, stage == "Roadian")

ggplot(pooled_colls_stage, aes(x = paleolat_code, y = n, group = clade, colour = clade)) +
  geom_line(size = 2) + geom_point(size = 2) + labs(x = "Palaeolatitude", y = "Collection counts") +
  coord_flip() + scale_x_continuous(limits = c(-90, 90)) +
  geom_vline(aes(xintercept = 0), colour = "black") + 
  scale_colour_manual(values = c("grey", "black")) + theme_classic()
